import QtQuick 2.3
import Fly.Components 1.0

FlyNotificationItem {
    id: notificationItem

    property bool paused: _notification && _notification.dataMap["paused"]
    property int elapsed: _notification && _notification.dataMap["elapsed"]

    caption.width: datetime.x - caption.x - 5

    description.visible: false
    description.y: height * 0.6
    description.height: height * 0.4

    icon.imagePath: "image://ThemeImageProvider/audio-input-microphone"
    icon.imageColorEnabled: true
    icon.imageColor: styles.colors.darkred

    function clicked() {
        root.startDetachedProcess("fly-record", []);
        return false; // close notification panel
    }

    function convertDurationToHHMMSS(duration) {
        duration = parseInt(duration / 1000)
        var hours = parseInt( duration / 3600 ) % 24;
        var min = parseInt( duration / 60 ) % 60;
        var sec = duration % 60;

        return (hours < 10 ? "0" + hours : hours) + ":" + (min < 10 ? "0" + min : min) + ":" + (sec < 10 ? "0" + sec : sec);
    }

    FlyLabel {
        id: datetime
        anchors { top: parent.top; right: parent.right; bottom: parent.verticalCenter; rightMargin: margin }
        text: convertDurationToHHMMSS(notificationItem.elapsed)
        font.pixelSize: description.font.pixelSize;
        color: styles.label.colorDisabled
        verticalAlignment: Text.AlignVCenter
    }

    FlySeparator { x: description.x; y: description.y - height + 1; width: description.width }

    Row {
        id: btnRow
        anchors.fill: description

        readonly property bool isRus: Qt.locale().name.substring(0,2) === "ru"

        // NOTE: currently there is no localization of custom notifications in fly-launcher
        function trString(str) {
            if(!isRus) return str;

            switch (str) {
            case "Resume":  return "Продолжить";
            case "Pause":   return "Пауза";
            case "Stop":    return "Стоп";
            }

            return str;
        }

        FlyMenuButton {
            width: parent.width / 2 - sep.width / 2
            text: paused ? btnRow.trString("Resume") : btnRow.trString("Pause")
            image.imagePath: paused
                             ? "image://ThemeImageProvider/audio-input-microphone"
                             : "image://ThemeImageProvider/media-playback-pause"
            image.imageColorEnabled: true
            image.imageColor: paused ? styles.colors.darkred : styles.highlightColor
            buttonRow.anchors.horizontalCenter: buttonRow.parent.horizontalCenter
            onClicked: if(_notification) _notification.newData("pause")
        }

        FlySeparator { id: sep; horizontal: false }

        FlyMenuButton {
            width: parent.width / 2 - sep.width / 2
            text: btnRow.trString("Stop")
            image.imagePath: "image://ThemeImageProvider/media-playback-stop"
            image.imageColorEnabled: true
            image.imageColor: styles.highlightColor
            buttonRow.anchors.horizontalCenter: buttonRow.parent.horizontalCenter
            onClicked: if(_notification) _notification.newData("stop")
        }
    }
}
